@@ -32,6 +32,7 @@ PROVISIONING_VERSIONS = {
     'rescue': 38,
     'unrescue': 38,
     'unhold': 85,
+    'service': 87,
 }
 """API microversions introducing provisioning verbs."""
 
@@ -87,8 +88,13 @@ DEPLOY_STEPS_VERSION = '1.69'
 CHANGE_BOOT_MODE_VERSION = '1.76'
 """API version in which boot_mode and secure_boot states can be changed"""
 
+FIRMWARE_VERSION = '1.86'
+"""API version in which firmware components of a node can be accessed"""
+
+
+class Resource(resource.Resource):
+    base_path: str
 
-class ListMixin:
     @classmethod
     def list(cls, session, details=False, **params):
         """This method is a generator which yields resource objects.
@@ -112,7 +118,7 @@ class ListMixin:
         base_path = cls.base_path
         if details:
             base_path += '/detail'
-        return super(ListMixin, cls).list(
+        return super().list(
             session, paginated=True, base_path=base_path, **params
         )
 
