@@ -456,7 +456,7 @@ class Proxy(proxy.Proxy):
         :return: The node boot device
         """
         res = self._get_resource(_node.Node, node)
-        return res.get_boot_device()
+        return res.get_boot_device(self)
 
     def set_node_boot_device(self, node, boot_device, persistent=False):
         """Set node boot device
@@ -479,7 +479,7 @@ class Proxy(proxy.Proxy):
         :return: The node boot device
         """
         res = self._get_resource(_node.Node, node)
-        return res.get_supported_boot_devices()
+        return res.get_supported_boot_devices(self)
 
     def set_node_boot_mode(self, node, target):
         """Make a request to change node's boot mode
@@ -1243,6 +1243,16 @@ class Proxy(proxy.Proxy):
         res = self._get_resource(_node.Node, node)
         return res.set_traits(self, traits)
 
+    def list_node_firmware(self, node):
+        """Lists firmware components for a node.
+
+        :param node: The value can be the name or ID of a node or a
+            :class:`~openstack.baremetal.v1.node.Node` instance.
+        :returns: A list of the node's firmware components.
+        """
+        res = self._get_resource(_node.Node, node)
+        return res.list_firmware(self)
+
     def volume_connectors(self, details=False, **query):
         """Retrieve a generator of volume_connector.
 
