@@ -10,10 +10,13 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import warnings
+
 from openstack.cloud import _utils
 from openstack import exceptions
 from openstack.identity.v3._proxy import Proxy
 from openstack import utils
+from openstack import warnings as os_warnings
 
 
 class IdentityCloudMixin:
@@ -384,31 +387,25 @@ class IdentityCloudMixin:
         try:
             user = self.get_user(name_or_id, **kwargs)
             if not user:
-                self.log.debug(
-                    "User {0} not found for deleting".format(name_or_id)
-                )
+                self.log.debug(f"User {name_or_id} not found for deleting")
                 return False
 
             self.identity.delete_user(user)
             return True
 
         except exceptions.SDKException:
-            self.log.exception(
-                "Error in deleting user {user}".format(user=name_or_id)
-            )
+            self.log.exception(f"Error in deleting user {name_or_id}")
             return False
 
     def _get_user_and_group(self, user_name_or_id, group_name_or_id):
         user = self.get_user(user_name_or_id)
         if not user:
-            raise exceptions.SDKException(
-                'User {user} not found'.format(user=user_name_or_id)
-            )
+            raise exceptions.SDKException(f'User {user_name_or_id} not found')
 
         group = self.get_group(group_name_or_id)
         if not group:
             raise exceptions.SDKException(
-                'Group {user} not found'.format(user=group_name_or_id)
+                f'Group {group_name_or_id} not found'
             )
 
         return (user, group)
@@ -731,7 +728,7 @@ class IdentityCloudMixin:
             self.identity.delete_endpoint(id)
             return True
         except exceptions.SDKException:
-            self.log.exception("Failed to delete endpoint {id}".format(id=id))
+            self.log.exception(f"Failed to delete endpoint {id}")
             return False
 
     def create_domain(self, name, description=None, enabled=True):
@@ -778,7 +775,7 @@ class IdentityCloudMixin:
             dom = self.get_domain(None, name_or_id)
             if dom is None:
                 raise exceptions.SDKException(
-                    "Domain {0} not found for updating".format(name_or_id)
+                    f"Domain {name_or_id} not found for updating"
                 )
             domain_id = dom['id']
 
@@ -1006,7 +1003,7 @@ class IdentityCloudMixin:
         group = self.identity.find_group(name_or_id, **kwargs)
         if group is None:
             raise exceptions.SDKException(
-                "Group {0} not found for updating".format(name_or_id)
+                f"Group {name_or_id} not found for updating"
             )
 
         group_ref = {}
@@ -1039,9 +1036,7 @@ class IdentityCloudMixin:
             return True
 
         except exceptions.SDKException:
-            self.log.exception(
-                "Unable to delete group {name}".format(name=name_or_id)
-            )
+            self.log.exception(f"Unable to delete group {name_or_id}")
             return False
 
     def list_roles(self, **kwargs):
@@ -1119,7 +1114,15 @@ class IdentityCloudMixin:
                     # proxy
                     filters['scope.' + k + '.id'] = filters[k]
                 del filters[k]
-        if 'os_inherit_extension_inherited_to' in filters:
+        if 'inherited_to' in filters:
+            filters['scope.OS-INHERIT:inherited_to'] = filters['inherited_to']
+            del filters['inherited_to']
+        elif 'os_inherit_extension_inherited_to' in filters:
+            warnings.warn(
+                "os_inherit_extension_inherited_to is deprecated. Use "
+                "inherited_to instead.",
+                os_warnings.OpenStackDeprecationWarning,
+            )
             filters['scope.OS-INHERIT:inherited_to'] = filters[
                 'os_inherit_extension_inherited_to'
             ]
@@ -1138,15 +1141,17 @@ class IdentityCloudMixin:
             * 'domain' (string) - Domain ID to be used as query filter.
             * 'system' (string) - System name to be used as query filter.
             * 'role' (string) - Role ID to be used as query filter.
-            * 'os_inherit_extension_inherited_to' (string) - Return inherited
-              role assignments for either 'projects' or 'domains'
+            * 'inherited_to' (string) - Return inherited
+              role assignments for either 'projects' or 'domains'.
+            * 'os_inherit_extension_inherited_to' (string) - Deprecated; use
+              'inherited_to' instead.
             * 'effective' (boolean) - Return effective role assignments.
             * 'include_subtree' (boolean) - Include subtree
 
               'user' and 'group' are mutually exclusive, as are 'domain' and
               'project'.
 
-        :returns: A list of indentity
+        :returns: A list of identity
             :class:`openstack.identity.v3.role_assignment.RoleAssignment`
             objects
         :raises: :class:`~openstack.exceptions.SDKException` if something goes
@@ -1182,6 +1187,16 @@ class IdentityCloudMixin:
             system_scope = filters.pop('system')
             filters['scope.system'] = system_scope
 
+        if 'os_inherit_extension_inherited_to' in filters:
+            warnings.warn(
+                "os_inherit_extension_inherited_to is deprecated. Use "
+                "inherited_to instead.",
+                os_warnings.OpenStackDeprecationWarning,
+            )
+            filters['inherited_to'] = filters.pop(
+                'os_inherit_extension_inherited_to'
+            )
+
         return list(self.identity.role_assignments(**filters))
 
     @_utils.valid_kwargs('domain_id')
@@ -1235,9 +1250,7 @@ class IdentityCloudMixin:
             self.identity.delete_role(role)
             return True
         except exceptions.SDKExceptions:
-            self.log.exception(
-                "Unable to delete role {name}".format(name=name_or_id)
-            )
+            self.log.exception(f"Unable to delete role {name_or_id}")
             raise
 
     def _get_grant_revoke_params(
@@ -1261,7 +1274,7 @@ class IdentityCloudMixin:
 
         data['role'] = self.identity.find_role(name_or_id=role)
         if not data['role']:
-            raise exceptions.SDKException('Role {0} not found.'.format(role))
+            raise exceptions.SDKException(f'Role {role} not found.')
 
         if user:
             # use cloud.get_user to save us from bad searching by name
