@@ -12,23 +12,22 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-
-import munch
 import ipaddress
 import socket
 
 from openstack import _log
+from openstack import exceptions
 from openstack import utils
-from openstack.cloud import exc
 
 
 NON_CALLABLES = (str, bool, dict, int, float, list, type(None))
 
 
-def find_nova_interfaces(addresses, ext_tag=None, key_name=None, version=4,
-                         mac_addr=None):
+def find_nova_interfaces(
+    addresses, ext_tag=None, key_name=None, version=4, mac_addr=None
+):
     ret = []
-    for (k, v) in iter(addresses.items()):
+    for k, v in iter(addresses.items()):
         if key_name is not None and k != key_name:
             # key_name is specified and it doesn't match the current network.
             # Continue with the next one
@@ -66,10 +65,12 @@ def find_nova_interfaces(addresses, ext_tag=None, key_name=None, version=4,
     return ret
 
 
-def find_nova_addresses(addresses, ext_tag=None, key_name=None, version=4,
-                        mac_addr=None):
-    interfaces = find_nova_interfaces(addresses, ext_tag, key_name, version,
-                                      mac_addr)
+def find_nova_addresses(
+    addresses, ext_tag=None, key_name=None, version=4, mac_addr=None
+):
+    interfaces = find_nova_interfaces(
+        addresses, ext_tag, key_name, version, mac_addr
+    )
     floating_addrs = []
     fixed_addrs = []
     for i in interfaces:
@@ -93,8 +94,7 @@ def get_server_ip(server, public=False, cloud_public=True, **kwargs):
                          private ip we expect shade to be able to reach
     """
     addrs = find_nova_addresses(server['addresses'], **kwargs)
-    return find_best_address(
-        addrs, public=public, cloud_public=cloud_public)
+    return find_best_address(addrs, public=public, cloud_public=cloud_public)
 
 
 def get_server_private_ip(server, cloud=None):
@@ -128,30 +128,34 @@ def get_server_private_ip(server, cloud=None):
         int_nets = cloud.get_internal_ipv4_networks()
         for int_net in int_nets:
             int_ip = get_server_ip(
-                server, key_name=int_net['name'],
+                server,
+                key_name=int_net['name'],
                 ext_tag='fixed',
                 cloud_public=not cloud.private,
-                mac_addr=fip_mac)
+                mac_addr=fip_mac,
+            )
             if int_ip is not None:
                 return int_ip
         # Try a second time without the fixed tag. This is for old nova-network
         # results that do not have the fixed/floating tag.
         for int_net in int_nets:
             int_ip = get_server_ip(
-                server, key_name=int_net['name'],
+                server,
+                key_name=int_net['name'],
                 cloud_public=not cloud.private,
-                mac_addr=fip_mac)
+                mac_addr=fip_mac,
+            )
             if int_ip is not None:
                 return int_ip
 
     ip = get_server_ip(
-        server, ext_tag='fixed', key_name='private', mac_addr=fip_mac)
+        server, ext_tag='fixed', key_name='private', mac_addr=fip_mac
+    )
     if ip:
         return ip
 
     # Last resort, and Rackspace
-    return get_server_ip(
-        server, key_name='private')
+    return get_server_ip(server, key_name='private')
 
 
 def get_server_external_ipv4(cloud, server):
@@ -185,8 +189,11 @@ def get_server_external_ipv4(cloud, server):
     ext_nets = cloud.get_external_ipv4_networks()
     for ext_net in ext_nets:
         ext_ip = get_server_ip(
-            server, key_name=ext_net['name'], public=True,
-            cloud_public=not cloud.private)
+            server,
+            key_name=ext_net['name'],
+            public=True,
+            cloud_public=not cloud.private,
+        )
         if ext_ip is not None:
             return ext_ip
 
@@ -194,8 +201,8 @@ def get_server_external_ipv4(cloud, server):
     # Much as I might find floating IPs annoying, if it has one, that's
     # almost certainly the one that wants to be used
     ext_ip = get_server_ip(
-        server, ext_tag='floating', public=True,
-        cloud_public=not cloud.private)
+        server, ext_tag='floating', public=True, cloud_public=not cloud.private
+    )
     if ext_ip is not None:
         return ext_ip
 
@@ -205,8 +212,8 @@ def get_server_external_ipv4(cloud, server):
 
     # Try to get an address from a network named 'public'
     ext_ip = get_server_ip(
-        server, key_name='public', public=True,
-        cloud_public=not cloud.private)
+        server, key_name='public', public=True, cloud_public=not cloud.private
+    )
     if ext_ip is not None:
         return ext_ip
 
@@ -240,19 +247,25 @@ def find_best_address(addresses, public=False, cloud_public=True):
         for address in addresses:
             try:
                 for count in utils.iterate_timeout(
-                        5, "Timeout waiting for %s" % address, wait=0.1):
+                    5, "Timeout waiting for %s" % address, wait=0.1
+                ):
                     # Return the first one that is reachable
                     try:
                         for res in socket.getaddrinfo(
-                                address, 22, socket.AF_UNSPEC,
-                                socket.SOCK_STREAM, 0):
+                            address,
+                            22,
+                            socket.AF_UNSPEC,
+                            socket.SOCK_STREAM,
+                            0,
+                        ):
                             family, socktype, proto, _, sa = res
                             connect_socket = socket.socket(
-                                family, socktype, proto)
+                                family, socktype, proto
+                            )
                             connect_socket.settimeout(1)
                             connect_socket.connect(sa)
                             return address
-                    except socket.error:
+                    except OSError:
                         # Sometimes a "no route to address" type error
                         # will fail fast, but can often come alive
                         # when retried.
@@ -267,12 +280,13 @@ def find_best_address(addresses, public=False, cloud_public=True):
             "The cloud returned multiple addresses %s:, and we could not "
             "connect to port 22 on either. That might be what you wanted, "
             "but we have no clue what's going on, so we picked the first one "
-            "%s" % (addresses, addresses[0]))
+            "%s" % (addresses, addresses[0])
+        )
     return addresses[0]
 
 
 def get_server_external_ipv6(server):
-    """ Get an IPv6 address reachable from outside the cloud.
+    """Get an IPv6 address reachable from outside the cloud.
 
     This function assumes that if a server has an IPv6 address, that address
     is reachable from outside the cloud.
@@ -280,6 +294,7 @@ def get_server_external_ipv6(server):
     :param server: the server from which we want to get an IPv6 address
     :return: a string containing the IPv6 address or None
     """
+    # Don't return ipv6 interfaces if forcing IPv4
     if server['accessIPv6']:
         return server['accessIPv6']
     addresses = find_nova_addresses(addresses=server['addresses'], version=6)
@@ -287,7 +302,7 @@ def get_server_external_ipv6(server):
 
 
 def get_server_default_ip(cloud, server):
-    """ Get the configured 'default' address
+    """Get the configured 'default' address
 
     It is possible in clouds.yaml to configure for a cloud a network that
     is the 'default_interface'. This is the network that should be used
@@ -300,22 +315,26 @@ def get_server_default_ip(cloud, server):
     """
     ext_net = cloud.get_default_network()
     if ext_net:
-        if (cloud._local_ipv6 and not cloud.force_ipv4):
+        if cloud._local_ipv6 and not cloud.force_ipv4:
             # try 6 first, fall back to four
             versions = [6, 4]
         else:
             versions = [4]
         for version in versions:
             ext_ip = get_server_ip(
-                server, key_name=ext_net['name'], version=version, public=True,
-                cloud_public=not cloud.private)
+                server,
+                key_name=ext_net['name'],
+                version=version,
+                public=True,
+                cloud_public=not cloud.private,
+            )
             if ext_ip is not None:
                 return ext_ip
     return None
 
 
 def _get_interface_ip(cloud, server):
-    """ Get the interface IP for the server
+    """Get the interface IP for the server
 
     Interface IP is the IP that should be used for communicating with the
     server. It is:
@@ -330,7 +349,7 @@ def _get_interface_ip(cloud, server):
     if cloud.private and server['private_v4']:
         return server['private_v4']
 
-    if (server['public_v6'] and cloud._local_ipv6 and not cloud.force_ipv4):
+    if server['public_v6'] and cloud._local_ipv6 and not cloud.force_ipv4:
         return server['public_v6']
     else:
         return server['public_v4']
@@ -351,7 +370,7 @@ def get_groups_from_server(cloud, server, server_vars):
     groups.append(region)
 
     # And one by cloud_region
-    groups.append("%s_%s" % (cloud_name, region))
+    groups.append(f"{cloud_name}_{region}")
 
     # Check if group metadata key in servers' metadata
     group = server['metadata'].get('group')
@@ -366,17 +385,17 @@ def get_groups_from_server(cloud, server, server_vars):
 
     for key in ('flavor', 'image'):
         if 'name' in server_vars[key]:
-            groups.append('%s-%s' % (key, server_vars[key]['name']))
+            groups.append('{}-{}'.format(key, server_vars[key]['name']))
 
     for key, value in iter(server['metadata'].items()):
-        groups.append('meta-%s_%s' % (key, value))
+        groups.append(f'meta-{key}_{value}')
 
     az = server_vars.get('az', None)
     if az:
         # Make groups for az, region_az and cloud_region_az
         groups.append(az)
-        groups.append('%s_%s' % (region, az))
-        groups.append('%s_%s_%s' % (cloud.name, region, az))
+        groups.append(f'{region}_{az}')
+        groups.append(f'{cloud.name}_{region}_{az}')
     return groups
 
 
@@ -405,15 +424,19 @@ def _get_supplemental_addresses(cloud, server):
     try:
         # Don't bother doing this before the server is active, it's a waste
         # of an API call while polling for a server to come up
-        if (cloud.has_service('network')
-                and cloud._has_floating_ips()
-                and server['status'] == 'ACTIVE'):
+        if (
+            cloud.has_service('network')
+            and cloud._has_floating_ips()
+            and server['status'] == 'ACTIVE'
+        ):
             for port in cloud.search_ports(
-                    filters=dict(device_id=server['id'])):
+                filters=dict(device_id=server['id'])
+            ):
                 # This SHOULD return one and only one FIP - but doing it as a
                 # search/list lets the logic work regardless
                 for fip in cloud.search_floating_ips(
-                        filters=dict(port_id=port['id'])):
+                    filters=dict(port_id=port['id'])
+                ):
                     fixed_net = fixed_ip_mapping.get(fip['fixed_ip_address'])
                     if fixed_net is None:
                         log = _log.setup_logging('openstack')
@@ -423,11 +446,13 @@ def _get_supplemental_addresses(cloud, server):
                             " with the floating ip in the neutron listing"
                             " does not exist in the nova listing. Something"
                             " is exceptionally broken.",
-                            dict(fip=fip['id'], server=server['id']))
+                            dict(fip=fip['id'], server=server['id']),
+                        )
                     else:
                         server['addresses'][fixed_net].append(
-                            _make_address_dict(fip, port))
-    except exc.OpenStackCloudException:
+                            _make_address_dict(fip, port)
+                        )
+    except exceptions.SDKException:
         # If something goes wrong with a cloud call, that's cool - this is
         # an attempt to provide additional data and should not block forward
         # progress
@@ -448,7 +473,12 @@ def add_server_interfaces(cloud, server):
     # not exist to remain consistent with the pre-existing missing values
     server['addresses'] = _get_supplemental_addresses(cloud, server)
     server['public_v4'] = get_server_external_ipv4(cloud, server) or ''
-    server['public_v6'] = get_server_external_ipv6(server) or ''
+    # If we're forcing IPv4, then don't report IPv6 interfaces which
+    # are likely to be unconfigured.
+    if cloud.force_ipv4:
+        server['public_v6'] = ''
+    else:
+        server['public_v6'] = get_server_external_ipv6(server) or ''
     server['private_v4'] = get_server_private_ip(server, cloud) or ''
     server['interface_ip'] = _get_interface_ip(cloud, server) or ''
 
@@ -456,11 +486,11 @@ def add_server_interfaces(cloud, server):
     # server record. Since we know them, go ahead and set them. In the case
     # where they were set previous, we use the values, so this will not break
     # clouds that provide the information
-    if cloud.private and server['private_v4']:
-        server['accessIPv4'] = server['private_v4']
+    if cloud.private and server.private_v4:
+        server['access_ipv4'] = server['private_v4']
     else:
-        server['accessIPv4'] = server['public_v4']
-    server['accessIPv6'] = server['public_v6']
+        server['access_ipv4'] = server['public_v4']
+    server['access_ipv6'] = server['public_v6']
 
     return server
 
@@ -468,7 +498,7 @@ def add_server_interfaces(cloud, server):
 def expand_server_security_groups(cloud, server):
     try:
         groups = cloud.list_server_security_groups(server)
-    except exc.OpenStackCloudException:
+    except exceptions.SDKException:
         groups = []
     server['security_groups'] = groups or []
 
@@ -481,7 +511,7 @@ def get_hostvars_from_server(cloud, server, mounts=None):
     expand_server_vars if caching is not set up. If caching is set up,
     the extra cost should be minimal.
     """
-    server_vars = add_server_interfaces(cloud, server)
+    server_vars = obj_to_munch(add_server_interfaces(cloud, server))
 
     flavor_id = server['flavor'].get('id')
     if flavor_id:
@@ -508,6 +538,11 @@ def get_hostvars_from_server(cloud, server, mounts=None):
         if image_name:
             server_vars['image']['name'] = image_name
 
+    # During the switch to returning sdk resource objects we need temporarily
+    # to force convertion to dict. This will be dropped soon.
+    if hasattr(server_vars['image'], 'to_dict'):
+        server_vars['image'] = server_vars['image'].to_dict(computed=False)
+
     volumes = []
     if cloud.has_service('volume'):
         try:
@@ -515,7 +550,7 @@ def get_hostvars_from_server(cloud, server, mounts=None):
                 # Make things easier to consume elsewhere
                 volume['device'] = volume['attachments'][0]['device']
                 volumes.append(volume)
-        except exc.OpenStackCloudException:
+        except exceptions.SDKException:
             pass
     server_vars['volumes'] = volumes
     if mounts:
@@ -529,7 +564,7 @@ def get_hostvars_from_server(cloud, server, mounts=None):
 
 
 def obj_to_munch(obj):
-    """ Turn an object with attributes into a dict suitable for serializing.
+    """Turn an object with attributes into a dict suitable for serializing.
 
     Some of the things that are returned in OpenStack are objects with
     attributes. That's awesome - except when you want to expose them as JSON
@@ -539,7 +574,7 @@ def obj_to_munch(obj):
     """
     if obj is None:
         return None
-    elif isinstance(obj, munch.Munch) or hasattr(obj, 'mock_add_spec'):
+    elif isinstance(obj, utils.Munch) or hasattr(obj, 'mock_add_spec'):
         # If we obj_to_munch twice, don't fail, just return the munch
         # Also, don't try to modify Mock objects - that way lies madness
         return obj
@@ -551,14 +586,14 @@ def obj_to_munch(obj):
         # the dict we get, but we also want it to fall through to object
         # attribute processing so that we can also get the request_ids
         # data into our resulting object.
-        instance = munch.Munch(obj)
+        instance = utils.Munch(obj)
     else:
-        instance = munch.Munch()
+        instance = utils.Munch()
 
     for key in dir(obj):
         try:
             value = getattr(obj, key)
-        # some attributes can be defined as a @propierty, so we can't assure
+        # some attributes can be defined as a @property, so we can't assure
         # to have a valid value
         # e.g. id in python-novaclient/tree/novaclient/v2/quotas.py
         except AttributeError:
