@@ -24,7 +24,6 @@ import requestsexceptions
 from openstack import _log
 from openstack.cloud import _object_store
 from openstack.cloud import _utils
-from openstack.cloud import exc
 from openstack.cloud import meta
 import openstack.config
 from openstack.config import cloud_region as cloud_region_mod
@@ -65,7 +64,7 @@ class _OpenStackCloudMixin:
     _SHADE_OBJECT_AUTOCREATE_KEY = 'x-object-meta-x-shade-autocreated'
 
     def __init__(self):
-        super(_OpenStackCloudMixin, self).__init__()
+        super().__init__()
 
         self.log = _log.setup_logging('openstack')
 
@@ -173,10 +172,10 @@ class _OpenStackCloudMixin:
                 name_key = 'username'
             else:
                 name_key = 'project_name'
-            id_key = '{prefix}_id'.format(prefix=prefix)
+            id_key = f'{prefix}_id'
             pop_keys(params, kwargs, name_key, id_key)
-            id_key = '{prefix}_domain_id'.format(prefix=prefix)
-            name_key = '{prefix}_domain_name'.format(prefix=prefix)
+            id_key = f'{prefix}_domain_id'
+            name_key = f'{prefix}_domain_name'
             pop_keys(params, kwargs, name_key, id_key)
 
         for key, value in kwargs.items():
@@ -283,14 +282,14 @@ class _OpenStackCloudMixin:
         if namespace is None:
             name_key = self.name
         else:
-            name_key = '%s:%s' % (self.name, namespace)
+            name_key = f'{self.name}:{namespace}'
 
         def generate_key(*args, **kwargs):
             # TODO(frickler): make handling arg keys actually work
             arg_key = ''
             kw_keys = sorted(kwargs.keys())
             kwargs_key = ','.join(
-                ['%s:%s' % (k, kwargs[k]) for k in kw_keys if k != 'cache']
+                [f'{k}:{kwargs[k]}' for k in kw_keys if k != 'cache']
             )
             ans = "_".join([str(name_key), fname, arg_key, kwargs_key])
             return ans
@@ -445,7 +444,8 @@ class _OpenStackCloudMixin:
                 {"vcpus": "<=5", "ram": "<=2048", "disk": "1"}
 
         :returns: A list subset of the original data set.
-        :raises: OpenStackCloudException on invalid range expressions.
+        :raises: :class:`~openstack.exceptions.SDKException` on invalid range
+            expressions.
         """
         filtered = []
 
@@ -491,10 +491,10 @@ class _OpenStackCloudMixin:
                 "Endpoint not found in %s cloud: %s", self.name, str(e)
             )
             endpoint = None
-        except exc.OpenStackCloudException:
+        except exceptions.SDKException:
             raise
         except Exception as e:
-            raise exc.OpenStackCloudException(
+            raise exceptions.SDKException(
                 "Error getting {service} endpoint on {cloud}:{region}:"
                 " {error}".format(
                     service=service_key,
@@ -525,7 +525,7 @@ class _OpenStackCloudMixin:
                 kwargs['min_version'] = version
                 kwargs['max_version'] = version
             endpoint = self.get_session_endpoint(service_key, **kwargs)
-        except exc.OpenStackCloudException:
+        except exceptions.SDKException:
             return False
         if endpoint:
             return True
