@@ -561,7 +561,7 @@ class Proxy(proxy.Proxy):
 
     # ======== Zone Shares ========
     def zone_shares(self, zone, **query):
-        """Retrieve a generator of zone sharess
+        """Retrieve a generator of zone shares
 
         :param zone: The zone ID or a
             :class:`~openstack.dns.v2.zone.Zone` instance
@@ -667,27 +667,33 @@ class Proxy(proxy.Proxy):
         identified_resources=None,
         filters=None,
         resource_evaluation_fn=None,
+        skip_resources=None,
     ):
-        # Delete all zones
-        for obj in self.zones():
-            self._service_cleanup_del_res(
-                self.delete_zone,
-                obj,
-                dry_run=dry_run,
-                client_status_queue=client_status_queue,
-                identified_resources=identified_resources,
-                filters=filters,
-                resource_evaluation_fn=resource_evaluation_fn,
-            )
-        # Unset all floatingIPs
-        # NOTE: FloatingIPs are not cleaned when filters are set
-        for obj in self.floating_ips():
-            self._service_cleanup_del_res(
-                self.unset_floating_ip,
-                obj,
-                dry_run=dry_run,
-                client_status_queue=client_status_queue,
-                identified_resources=identified_resources,
-                filters=filters,
-                resource_evaluation_fn=resource_evaluation_fn,
-            )
+        if not self.should_skip_resource_cleanup("zone", skip_resources):
+            # Delete all zones
+            for obj in self.zones():
+                self._service_cleanup_del_res(
+                    self.delete_zone,
+                    obj,
+                    dry_run=dry_run,
+                    client_status_queue=client_status_queue,
+                    identified_resources=identified_resources,
+                    filters=filters,
+                    resource_evaluation_fn=resource_evaluation_fn,
+                )
+
+        if not self.should_skip_resource_cleanup(
+            "floating_ip", skip_resources
+        ):
+            # Unset all floatingIPs
+            # NOTE: FloatingIPs are not cleaned when filters are set
+            for obj in self.floating_ips():
+                self._service_cleanup_del_res(
+                    self.unset_floating_ip,
+                    obj,
+                    dry_run=dry_run,
+                    client_status_queue=client_status_queue,
+                    identified_resources=identified_resources,
+                    filters=filters,
+                    resource_evaluation_fn=resource_evaluation_fn,
+                )
