@@ -13,8 +13,7 @@
 import os
 import warnings
 
-from openstack.cloud import exc
-from openstack import exceptions
+from openstack import exceptions as exc
 from openstack.image.v1 import image as _image
 from openstack import proxy
 from openstack import utils
@@ -128,7 +127,7 @@ class Proxy(proxy.Proxy):
             or 'all_stores' in kwargs
             or 'all_stores_must_succeed' in kwargs
         ):
-            raise exceptions.InvalidRequest(
+            raise exc.InvalidRequest(
                 "Glance v1 does not support stores or image import"
             )
 
@@ -151,7 +150,7 @@ class Proxy(proxy.Proxy):
             container_format = 'bare'
 
         if data and filename:
-            raise exceptions.SDKException(
+            raise exc.SDKException(
                 'Passing filename and data simultaneously is not supported'
             )
 
@@ -163,7 +162,7 @@ class Proxy(proxy.Proxy):
             )
 
         if validate_checksum and data and not isinstance(data, bytes):
-            raise exceptions.SDKException(
+            raise exc.SDKException(
                 'Validating checksum is not possible when data is not a '
                 'direct binary object'
             )
@@ -296,16 +295,16 @@ class Proxy(proxy.Proxy):
             image = self._connection._get_and_munchify(
                 'image',
                 self.put(
-                    '/images/{id}'.format(id=image.id),
+                    f'/images/{image.id}',
                     headers=headers,
                     data=image_data,
                 ),
             )
-        except exc.OpenStackCloudHTTPError:
+        except exc.HttpException:
             self.log.debug("Deleting failed upload of image %s", name)
             try:
-                self.delete('/images/{id}'.format(id=image.id))
-            except exc.OpenStackCloudHTTPError:
+                self.delete(f'/images/{image.id}')
+            except exc.HttpException:
                 # We're just trying to clean up - if it doesn't work - shrug
                 self.log.warning(
                     "Failed deleting image after we failed uploading it.",
@@ -435,10 +434,10 @@ class Proxy(proxy.Proxy):
         img_props = {}
         for k, v in iter(properties.items()):
             if image.properties.get(k, None) != v:
-                img_props['x-image-meta-{key}'.format(key=k)] = v
+                img_props[f'x-image-meta-{k}'] = v
         if not img_props:
             return False
-        self.put('/images/{id}'.format(id=image.id), headers=img_props)
+        self.put(f'/images/{image.id}', headers=img_props)
         return True
 
     def update_image_properties(
@@ -470,7 +469,7 @@ class Proxy(proxy.Proxy):
         for k, v in iter(kwargs.items()):
             if v and k in ['ramdisk', 'kernel']:
                 v = self._connection.get_image_id(v)
-                k = '{0}_id'.format(k)
+                k = f'{k}_id'
             img_props[k] = v
 
         return self._update_image_properties(image, meta, img_props)
